﻿using Kivii.Contents.Entities;
using Kivii.Contents.Seeyon.Extensions;
using Kivii.DataAnnotations;
using Kivii.Seeyon;
using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.Threading.Tasks;

namespace Kivii.Contents.Seeyon.Entities
{
    [Api(Description = "OA新闻")]
    public class ContentNew : Content, IEntityIsSeeyonApply
    {
        /// <summary>
        /// 新闻版块id，根据[获取新闻版块信息]接口获得
        /// </summary>
        [Ignore]
        public string typeId { get; set; }

        /// <summary>
        /// 是否允许打印赋值"0 或者1"
        /// </summary>
        [Ignore]
        public string ext2 { get; set; }

        /// <summary>
        /// 是否显示发布人 赋值"false 或者 true"
        /// </summary>
        [Ignore]
        public string showPublishUserFlag { get; set; }

        public object OnGetApplyResult(Guid Kvid, object Result, string Message)
        {
            return null;
        }
        public object OnGetApplyResult(List<Guid> Kvids, object Result, string Message)
        {
            return null;
        }
        public object OnSubmitApplyForm<T>(Guid Kvid)
        {
            return null;
        }

        public object OnSubmitApplyForm<T>(T form)
        {
            form.ThrowIfNull("请传入新闻内容");
            var news = form as ContentNew;
            var client = new JsonServiceClient(Configs.BaseUrl);
            var session = KiviiContext.Request.GetSession();

            var requestForm = news.ConvertToNew(client, session);
            var response = client.RequestNew_Content(requestForm, session);
            var rtns = new RestfulExecutionResponse<ResponseNew_Content>();
            rtns.Results = new List<ResponseNew_Content>();
            rtns.Results.Add(response);

            return rtns;
        }
    }

    public class New_Content
    {
        /// <summary>
        /// 单位Id，默认值，OA提供
        /// </summary>
        public string accountId { get; set; }

        /// <summary>
        /// 新闻版块id，根据[获取新闻版块信息]接口获得
        /// </summary>
        public string typeId { get; set; }

        /// <summary>
        /// 摘要信息
        /// </summary>
        public string brief { get; set; }

        /// <summary>
        /// 关键字
        /// </summary>
        public string keywords { get; set; }

        /// <summary>
        /// 发起者部门名称
        /// </summary>
        public string publishDepartmentName { get; set; }

        /// <summary>
        /// 发新闻人员的登录名（此人员必须具有发起权限）
        /// </summary>
        public string senderuser { get; set; }

        /// <summary>
        /// 正文信息 例:<p>&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;<strong>测试公告</strong></p><p>&nbsp; &nbsp; &nbsp; &nbsp; 测试公告第二段</p>
        /// </summary>
        public string content { get; set; }

        /// <summary>
        /// HTML
        /// </summary>
        public string dataFormat { get; set; }

        /// <summary>
        /// 默认""
        /// </summary>
        public string ext5 { get; set; }

        /// <summary>
        /// 新闻标题
        /// </summary>
        public string title { get; set; }

        /// <summary>
        /// 草稿状态：赋值"null";直接发布：赋值"0"
        /// </summary>
        public string ext3 { get; set; }

        /// <summary>
        /// 草稿状态：赋值"null";直接发布：赋值"30"
        /// </summary>
        public string state { get; set; }

        /// <summary>
        /// 发布日期
        /// </summary>
        public string publishDate { get; set; }

        /// <summary>
        /// 发布人ID，赋值""
        /// </summary>
        public string publishUserId { get; set; }

        /// <summary>
        /// 创建日期
        /// </summary>
        public string createDate { get; set; }

        /// <summary>
        /// 访问记录信息赋值"0"
        /// </summary>
        public string ext1 { get; set; }

        /// <summary>
        /// 是否允许打印赋值"0 或者1"
        /// </summary>
        public string ext2 { get; set; }

        /// <summary>
        /// 是否显示发布人 赋值"false 或者 true"
        /// </summary>
        public string showPublishUserFlag { get; set; }

        /// <summary>
        /// 阅读计数，赋值0
        /// </summary>
        public string readCount { get; set; }

        /// <summary>
        /// 附件标记，暂不支持附件，赋值"false"
        /// </summary>
        public string attachmentsFlag { get; set; }
    }

    public class ResponseNew_Content
    {
        /// <summary>
        /// 
        /// </summary>
        public string id { get; set; }

        /// <summary>
        /// 
        /// </summary>
        public string title { get; set; }

        /// <summary>
        /// 
        /// </summary>
        public string typeId { get; set; }

        /// <summary>
        /// 
        /// </summary>
        public string typeName { get; set; }

        /// <summary>
        /// 
        /// </summary>
        public string publishScope { get; set; }

        /// <summary>
        /// 
        /// </summary>
        public string publishDepartmentId { get; set; }

        /// <summary>
        /// 
        /// </summary>
        public string brief { get; set; }

        /// <summary>
        /// 
        /// </summary>
        public string shortContent { get; set; }

        /// <summary>
        /// 
        /// </summary>
        public string keywords { get; set; }

        /// <summary>
        /// 
        /// </summary>
        public string dataFormat { get; set; }

        /// <summary>
        /// 
        /// </summary>
        public string createDate { get; set; }

        /// <summary>
        /// 
        /// </summary>
        public string createUser { get; set; }

        /// <summary>
        /// 
        /// </summary>
        public string createUserName { get; set; }

        /// <summary>
        /// 
        /// </summary>
        public string auditDate { get; set; }

        /// <summary>
        /// 
        /// </summary>
        public string auditUserId { get; set; }

        /// <summary>
        /// 
        /// </summary>
        public string auditAdvice { get; set; }

        /// <summary>
        /// 
        /// </summary>
        public string publishDate { get; set; }

        /// <summary>
        /// 
        /// </summary>
        public string publishUserId { get; set; }

        /// <summary>
        /// 
        /// </summary>
        public string publishDepartmentName { get; set; }

        /// <summary>
        /// 
        /// </summary>
        public string pigeonholeDate { get; set; }

        /// <summary>
        /// 
        /// </summary>
        public string pigeonholeUserId { get; set; }

        /// <summary>
        /// 
        /// </summary>
        public string pigeonholePath { get; set; }

        /// <summary>
        /// 
        /// </summary>
        public string updateDate { get; set; }

        /// <summary>
        /// 
        /// </summary>
        public string updateUser { get; set; }

        /// <summary>
        /// 
        /// </summary>
        public string readCount { get; set; }

        /// <summary>
        /// 
        /// </summary>
        public string topOrder { get; set; }

        /// <summary>
        /// 
        /// </summary>
        public string state { get; set; }

        /// <summary>
        /// 
        /// </summary>
        public string deletedFlag { get; set; }

        /// <summary>
        /// 
        /// </summary>
        public string accountId { get; set; }

        /// <summary>
        /// 
        /// </summary>
        public string attachmentsFlag { get; set; }

        /// <summary>
        /// 
        /// </summary>
        public string imageNews { get; set; }

        /// <summary>
        /// 
        /// </summary>
        public string focusNews { get; set; }

        /// <summary>
        /// 
        /// </summary>
        public string imageId { get; set; }

        /// <summary>
        /// 
        /// </summary>
        public string showPublishUserFlag { get; set; }

        /// <summary>
        /// 
        /// </summary>
        public string showPublishName { get; set; }

        /// <summary>
        /// 
        /// </summary>
        public string shareDajia { get; set; }

        /// <summary>
        /// 
        /// </summary>
        public string shareWeixin { get; set; }

        /// <summary>
        /// 
        /// </summary>
        public string imgUrl { get; set; }

        /// <summary>
        /// 
        /// </summary>
        public string praise { get; set; }

        /// <summary>
        /// 
        /// </summary>
        public string praiseSum { get; set; }

        /// <summary>
        /// 
        /// </summary>
        public string replyNumber { get; set; }

        /// <summary>
        /// 
        /// </summary>
        public string replyTime { get; set; }

        /// <summary>
        /// 
        /// </summary>
        public string spaceType { get; set; }

        /// <summary>
        /// 
        /// </summary>
        public string commentPermit { get; set; }

        /// <summary>
        /// 
        /// </summary>
        public string messagePermit { get; set; }

        /// <summary>
        /// 
        /// </summary>
        public string content { get; set; }

        /// <summary>
        /// 
        /// </summary>
        public string readFlag { get; set; }

        /// <summary>
        /// 
        /// </summary>
        public string noEdit { get; set; }

        /// <summary>
        /// 
        /// </summary>
        public string noDelete { get; set; }

        /// <summary>
        /// 
        /// </summary>
        public string showBriefArea { get; set; }

        /// <summary>
        /// 
        /// </summary>
        public string showKeywordsArea { get; set; }

        /// <summary>
        /// 
        /// </summary>
        public string topNumberOrder { get; set; }

        /// <summary>
        /// 
        /// </summary>
        public string writePublish { get; set; }

        /// <summary>
        /// 
        /// </summary>
        public string choosePublshId { get; set; }

        /// <summary>
        /// 
        /// </summary>
        public string publishChoose { get; set; }

        /// <summary>
        /// 
        /// </summary>
        public string publishMemberName { get; set; }

        /// <summary>
        /// 
        /// </summary>
        public string writePermitFlag { get; set; }

        /// <summary>
        /// 
        /// </summary>
        public string recordRead { get; set; }

        /// <summary>
        /// 
        /// </summary>
        public string openRecordRead { get; set; }

        /// <summary>
        /// 
        /// </summary>
        public string topNumberGroup { get; set; }

        /// <summary>
        /// 
        /// </summary>
        public string topNumberUnit { get; set; }

        /// <summary>
        /// 
        /// </summary>
        public string auditType { get; set; }

        /// <summary>
        /// 
        /// </summary>
        public string outPermit { get; set; }

    }

    public class NewsType
    {
        /// <summary>
        /// 新闻版块主键
        /// </summary>
        public string id { get; set; }

        /// <summary>
        /// 新闻版块名称
        /// </summary>
        public string typeName { get; set; }

        /// <summary>
        /// 新闻版块名称
        /// </summary>
        public string usedFlag { get; set; }

        /// <summary>
        /// 新闻版块描述
        /// </summary>
        public string description { get; set; }

        /// <summary>
        /// 新闻版块是否审核
        /// </summary>
        public string auditFlag { get; set; }

        /// <summary>
        /// 新闻版块审核员ID
        /// </summary>
        public string auditUser { get; set; }

        /// <summary>
        /// 新闻版块创建时间
        /// </summary>
        public string createDate { get; set; }

        /// <summary>
        /// 新闻版块创建时间
        /// </summary>
        public string createUser { get; set; }

        /// <summary>
        /// 新闻版块创建人ID
        /// </summary>
        public string createUserName { get; set; }

        /// <summary>
        /// 新闻版块最近更新时间
        /// </summary>
        public string updateDate { get; set; }

        /// <summary>
        /// 新闻版块最近更新人ID
        /// </summary>
        public string updateUser { get; set; }

        /// <summary>
        /// 	新闻版块所属单位ID
        /// </summary>
        public string accountId { get; set; }

        /// <summary>
        /// 新闻版块所在空间类型，3：集团 2：单位 1：部门
        /// </summary>
        public string spaceType { get; set; }

        /// <summary>
        /// 新闻版块创建人名称
        /// </summary>
        public string outterPermit { get; set; }

        /// <summary>
        /// 
        /// </summary>
        public string isAuditorModify { get; set; }

        /// <summary>
        /// 新闻版块中新闻是否允许外部人员查看
        /// </summary>
        public string commentPermit { get; set; }

        /// <summary>
        /// 
        /// </summary>
        public string topNumber { get; set; }

        /// <summary>
        /// 授权此新闻版块发起新闻权限的人员ID
        /// </summary>
        public string managerUserIds { get; set; }

        /// <summary>
        /// 授权此新闻版块发起新闻权限的人员名称
        /// </summary>
        public string writeUserIds { get; set; }

        /// <summary>
        /// 
        /// </summary>
        public string writeUserNames { get; set; }

        /// <summary>
        /// 
        /// </summary>
        public string canNewOfCurrent { get; set; }

        /// <summary>
        /// 
        /// </summary>
        public string canAdminOfCurrent { get; set; }

        /// <summary>
        /// 
        /// </summary>
        public string canAuditOfCurrent { get; set; }

        /// <summary>
        /// 
        /// </summary>
        public string auditPending { get; set; }

        /// <summary>
        /// 
        /// </summary>
        public string defaultPublish { get; set; }

        /// <summary>
        /// 
        /// </summary>
        public string finalPublish { get; set; }

        /// <summary>
        /// 
        /// </summary>
        public string writePermit { get; set; }

        /// <summary>
        /// 
        /// </summary>
        public string auditType { get; set; }

        /// <summary>
        /// 新闻版块审计管理员名称
        /// </summary>
        public string auditUserName { get; set; }

        /// <summary>
        /// 
        /// </summary>
        public string showManageButton { get; set; }

        /// <summary>
        /// 
        /// </summary>
        public string managerUserNames { get; set; }

    }
}
