﻿using Kivii.Auth;
using Kivii.Contents.Entities;
using Kivii.Contents.Seeyon.Entities;
using Kivii.Seeyon.Entities;
using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.Threading.Tasks;

namespace Kivii.Contents.Seeyon.Extensions
{
    internal static class NewExtension
    {
        public static ResponseToken RequestRestToken(this JsonServiceClient client, string loginName)
        {
            if (client == null) throw new ArgumentNullException("client");
            if (loginName.IsNullOrEmpty()) throw new ArgumentNullException("loginName");

            var request = new RequestRestToken();
            request.userName = Configs.restUserName;
            request.password = Configs.restPassword;
            request.loginName = loginName.ToLower();
            var rtns = client.Post<ResponseToken>($"{Configs.RouteRestToken}", request);
            return rtns;
        }

        public static List<NewsType> GetNewsType(this JsonServiceClient client, IAuthSession session)
        {
            if (client == null) throw new ArgumentNullException("client");
            var token = client.RequestRestToken(session.UserAuthName);
            var rtns = client.Get<List<NewsType>>($"{Configs.RouteNewsType}?token={token.id}");
            return rtns;
        }

        public static New_Content ConvertToNew(this ContentNew content, JsonServiceClient client, IAuthSession session)
        {
            var token = client.RequestRestToken(session.UserAuthName);
            var rtns = new New_Content();
            rtns.accountId = Configs.accountId;
            rtns.typeId = content.typeId.IsNullOrEmpty() ? "" : content.typeId;
            rtns.brief = content.Summary.IsNullOrEmpty() ? "" : content.Summary;
            rtns.keywords = content.SubTitle.IsNullOrEmpty() ? "" : content.SubTitle;
            rtns.publishDepartmentName = KiviiContext.CurrentMember.DepartmentName;
            rtns.senderuser = token.bindingUser.loginName;
            rtns.content = content.DisplayContent;
            rtns.dataFormat = "HTML";
            rtns.ext5 = "";
            rtns.title = content.Title;
            rtns.ext3 = "0";
            rtns.state = "30";
            rtns.publishDate = content.PublishDate == null ? DateTime.Now.ToString("yyyy-MM-dd HH:mm:ss") : content.PublishDate.Value.ToString("yyyy-MM-dd HH:mm:ss");
            rtns.publishUserId = "";
            rtns.createDate = content.CreateTime.ToString("yyyy-MM-dd HH:mm:ss");
            rtns.ext1 = "0";
            rtns.ext2 = content.ext2.IsNullOrEmpty() ? "0" : content.ext2;
            rtns.showPublishUserFlag = content.showPublishUserFlag.IsNullOrEmpty() ? "false" : content.showPublishUserFlag;
            rtns.readCount = "0";
            rtns.attachmentsFlag = "false";
            return rtns;
        }

        public static ResponseNew_Content RequestNew_Content(this JsonServiceClient client, New_Content request, IAuthSession session)
        {
            if (client == null) throw new ArgumentNullException("client");
            if (request == null) throw new ArgumentNullException("request");
            var json = Kivii.Text.JsonSerializer.SerializeToString(request);
            Console.WriteLine(json);
            var token = client.RequestRestToken(session.UserAuthName);
            var rtns = client.Post<ResponseNew_Content>($"{Configs.RouteContentNew}?token={token.id}", request);

            return rtns;
        }
    }
}
